#!/bin/bash

# Description:
#
# This script exports all outlook data (emails, contacts, calendars etc.)
# into plain text files that can be used as import files for other clients
# like Evolution.


# --- LEGAL INFORMATION --------------------------------------------------------
# THE AUTHOR OF THIS SCRIPT HEREBY GIVES UP ALL RIGHTS ALLOWING YOU TO DO
# WHAT YOU WANT (E. G. COMMERCIAL AND NON-COMMERCIAL USE OF ORIGINAL OR MODIFIED
# SCRIPTS WITHOUT REFERING TO THE ORIGINAL SOURCE).
# THE AUTHOR OF THIS SCRIPT WANTS TO STAY ANONYMOUS BUT CAN BE CONTACTED
# VIA THE USER NAME "DANUBIO" AT THE WIKI SITE "wiki.ubuntuusers.de" WHERE
# THE ORIGINAL VERSION OF THIS SCRIPT HAS BEEN PUBLISHED FIRST UNDER THE
# (WIKI PAGE) NAME "OUTLOOK2EVOLUTION".
# ------------------------------------------------------------------------------


# #######################################################################
# Change log (date format is mm/dd/yyyy):
# 01/01/2011 Initial version
# #######################################################################


# ------------------ Variables ----------------------------------------------

# Get the absolute path the script is executed from (without a trailing slash)
scriptpath="$(dirname $(readlink -f ${BASH_SOURCE[0]}))"



# Set this variable to the absolute path of the readpst bin file
# that shall be used to export the outlook data.
# Default: Look in same path as this script
myreadpst="$scriptpath/readpst"
#myreadpst="readpst"	# Enable this setting to use your locally installed version of readpst


# ----------------- Code ----------------------------------------------------

clear

# Show warning when readpst is not found...
if [ ! -f "$myreadpst" ]
then
    echo "WARNING: No 'readpst' program found in same folder as this script:"
    echo "         $myreadpst"
    echo "         Make sure that you executed the '1_setup_packages.sh' successfully"
    echo "         before calling this script!"
    echo "         If you want to use the the locally installed 'readpst' instead"
    echo "         change the variable 'myreadpst' in this script."
    echo "         Make sure the locally installed version is new enough for you."
    echo
fi


# Do a test call to show the version information
echo "==== Version information about readpst: ======"
"$myreadpst" -V
echo "=============================================="
echo



if [ -z "$1" ] # exit if no args given
then
    echo "Exports all emails, contacts, calendars and notes"
    echo "from an outlook pst file."
    echo "Emails are exported into mbox files (one file per outlook folder)."
    echo
    echo "Usage: '$(basename $0) <name-of-your-outlook-pst-file>'"
    echo "Example: $(basename $0) outlook.pst"
    echo
    echo "Note: The 'readpst' tool must be installed before calling these scripts:"
    echo "          1_setup_packages.sh"
    echo "          2_build_libpst.sh"
    echo "      (or 'sudo apt-get readpst' to use default version of your linux)"
    echo
    exit -1
fi

echo "----- Started raw export of outlook emails..."

# Remove an existing export directory
if [ -d "outlook_raw" ]; then
  echo "Removing existing outlook_raw folder..."
  rm -f -r "outlook_raw"
fi

echo "Creating new outlook_raw folder..."
mkdir outlook_raw

echo "Starting the export now. This can take a long time..."
"$myreadpst" "$1" -o outlook_raw -r > outlook_raw.log

echo "----- Finished raw export!"

exit 0

