#!/bin/bash

# Description:
#
# Script to prepare contacts exported from Outlook into a file format
# suitable to be imported into Evolution.
# Also describes the rquired steps to import the contacts to evolution
# manually (since there is no easy automation via shell script for that)...

# IMPORTANT:
# You need to build your own libpst from the sources
# to get new features and bug fixes
# (see description in the file "2_build_libpst.sh")           

# !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
# Without the new version (containing this patch) you will loose
# - the notes in your contacts and
# - the categories in the contacts and calendar events!
# !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

# Known limitations...
# - URL (work) gets lost!
# - Birthdays shifted sometimes by the time diff of creation local time to UTC
# - Birthdays before 1/1/1970 are set to 1/1/1970 !!!
# - File encodings are not always perfect (special characters my appear scrambled
#   depending on the device and software the contact has been created)


# --- LEGAL INFORMATION --------------------------------------------------------
# THE AUTHOR OF THIS SCRIPT HEREBY GIVES UP ALL RIGHTS ALLOWING YOU TO DO
# WHAT YOU WANT (E. G. COMMERCIAL AND NON-COMMERCIAL USE OF ORIGINAL OR MODIFIED
# SCRIPTS WITHOUT REFERING TO THE ORIGINAL SOURCE).
# THE AUTHOR OF THIS SCRIPT WANTS TO STAY ANONYMOUS BUT CAN BE CONTACTED
# VIA THE USER NAME "DANUBIO" AT THE WIKI SITE "wiki.ubuntuusers.de" WHERE
# THE ORIGINAL VERSION OF THIS SCRIPT HAS BEEN PUBLISHED FIRST UNDER THE
# (WIKI PAGE) NAME "OUTLOOK2EVOLUTION".
# ------------------------------------------------------------------------------


# #######################################################################
# Change log (date format is mm/dd/yyyy):
# 01/01/2011 Initial version
# 08/26/2011 Added script output to describe the steps how contacts can
#            be imported into Evolution
# #######################################################################


# Todos:
# - How to fix bugs for contacts created with WindowsMobile and synchronized
#   with Outlook:
#   - The date is different for one day if the contact has been first created in WindowsMobile Device.
#   - Possible Reason: The BDay is stored in UTC time (hour and minute) that was derived from the local time
#                      (instead of just storing the date)
# - Check wrong field mappings (use a dummy vcard containing all evolution fields?)
# - Fix birth dates (when specified as local time they move +/- one day!!!
#   Background:
#   TZ:+0100: This property specifies information related to the standard time zone of the vCard object.
#   Time zones east of UTC are positive numbers. Time zones west of UTC are negative numbers.


# ----------------------------------------------------------------------------
# To convert character encodings of the file/folder names and the file contents
# to Linux/Ubuntu without loosing special characters you have to specify the
# encoding of your Outlook file.
#
# Source endcoding - change this value accordingly when using a non european outlook version
# For a list of valid encodings see (list of encoding values):
# http://www.debian.org/doc/manuals/reference/ch11.en.html#list-of-encoding-values
# 
# File and folder names can be converted independently from the file contents
# since this seems to be required for some Outlook data files for unknown reasons.
FILE_NAME_ENCDN=iso-8859-1
FILE_CONTENT_ENCDN=iso-8859-1
#UTF-8
# ----------------------------------------------------------------------------



# ----------------------------------------------------------------------------
# MAIN
# ----------------------------------------------------------------------------


clear


if [ ! -d "outlook_raw" ];
  then

  echo "ERROR: The sub folder 'outlook_raw' does not exist!"
  echo "Please execute the script './3_export_outlook_data.sh' first"
  echo "before calling this script!"

  exit -1
fi



echo "Starting the conversion of the exported contacts..."



# Set the field delimiter chars to "new line" and ??? (why b?)
# This is required to overcome problems with files and folders containing spaces
# etc. within their name (their file name will be split into part instead
# of treating them as on file name because spaces and new lines are filed
# separators by default!).
IFS=$(echo -en "\n\b")

#echo "IFS=$IFS" | od -b  # debug output



# cd "outlook_raw"	# not required, we find the file using the find command



# locate contacts file ("find")
echo "Trying to find the contacts file (exported from Outlook)..."

for aFile in $(find "outlook_raw" -name contacts -type f)
do

    echo "Found contacts file in: $aFile"

    # Apply the file content encoding conversion to a copy of the file!
    # It is unclear when this is required. Just check your imported data after this
    # script run successfuly to check out whether the special character within your data
    # are displayed wrongly.
    iconv -f $FILE_CONTENT_ENCDN -t UTF-8 "$aFile" > "$aFile.converted" 
    echo "Converting contacts file encoding into new file..."
    echo "   $aFile.converted"
    # For testing only: iconv -f iso-8859-1 -t UTF-8 "$aFile" > "$aFile.converted"


done


echo "=========================================================================="
echo "Finished! The contacts can now be imported into Evolution using the file"
echo "'$aFile' (Outlook encoding) or '$aFile.converted' ($FILE_CONTENT_ENCDN encoding)!"
echo
echo "Steps to import the contacts by using a new address book:"
echo
echo "1. Open evolution"
echo "2. Click the 'Contacts' button"
echo "3. Select the menu item 'File' -> 'New' -> 'address book'"
echo "   Set 'Type' to 'local (on this computer)'"
echo "   Uncheck 'default address book' (if checked)"
echo "4. Go to 'File' -> 'Import'"
echo "5. Click 'Forward'"
echo "6. Select 'Import a single file' and click 'Forward'"
echo "7. Browse for the file in the file menu and select it"
echo "8. Set the File Type to 'vcard'"
echo "9. click 'Forward'"
echo "10. As import location select 'Personal' under 'on this computer'"
echo "    (or a previously added new address box) and click 'Forward'"
echo "11. Finally click 'Import'"
echo
echo "The vcard file will be imported into Evolution then..."
#echo "The contact file of Evolution is stored in"
#echo " /home/<username>/.evolution/addressbook/local/system/addressbook.db"
#echo

